@@ -1,4 +1,5 @@
 #!/bin/env perl 
+#!d:\perl\bin\perl.exe 
 
 use SOAP::Lite +autodispatch 
   => (uri => 'urn:', 
@@ -6,6 +7,7 @@ use SOAP::Lite +autodispatch
       # proxy => 'http://localhost/cgi-bin/soap.cgi', # local CGI server
       # proxy => 'http://localhost/',                 # local daemon server
       # proxy => 'http://localhost/soap',             # local mod_perl server
+      # proxy => 'https://localhost/soap',            # local mod_perl SECURE server
       on_fault => sub {
         my($soap, $res) = @_;
         ref $res ? die(join "\n", "--- SOAP FAULT ---", $res->faultcode, $res->faultstring, $res->faultdetail, '') 
@@ -14,7 +16,7 @@ use SOAP::Lite +autodispatch
      )
 ;
 
-my $e = new Chatbot::Eliza 'Your name';
+my $e = new My::Chatbot::Eliza 'Your name';
 print "Talk, please\n> ";
 while (<>) {
   print $e->transform;
